#include "lunarlander.h"
#include "ui_lunarlander.h"

LunarLander::LunarLander(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::LunarLander)
{
    timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(updateLanding()));
    //timer->start(1000);

    ui->setupUi(this);

    scene = new QGraphicsScene(this);
    ui->graphicsView->setScene(scene);
    lander = new modul;
    pod = new QGraphicsRectItem;
    scene->addItem(pod);
    pod->setVisible(false);
}

LunarLander::~LunarLander()
{
    delete ui;
}

void LunarLander::updateLanding()
{
    QNetworkAccessManager *manager = new QNetworkAccessManager(this); //nastavi posilac pozadavku
    connect(manager, SIGNAL(finished(QNetworkReply*)),this,SLOT(replyFinished(QNetworkReply *))); //spoji s funkci replyFinished()

    manager->get(QNetworkRequest(QUrl(location)));
}

void LunarLander::replyFinished(QNetworkReply *rep)
{
    QMessageBox msgBox;
    QString str(rep->readAll());
    QStringList list = str.split("\r\n",QString::SkipEmptyParts);
    if(list[0] == "Krach!")
    {
        timer->stop();
        ui->pushButton_2->setStyleSheet("QPushButton {background-color: red}");
        ui->pushButton_3->setStyleSheet("QPushButton {background-color: red}");
        ui->pushButton_4->setStyleSheet("QPushButton {background-color: red}");
        msgBox.setText("Krach!");
        msgBox.exec();

    }
    else if(list[0] == "Zdar!")
    {
        timer->stop();
        ui->pushButton_2->setStyleSheet("QPushButton {background-color: red}");
        ui->pushButton_3->setStyleSheet("QPushButton {background-color: red}");
        ui->pushButton_4->setStyleSheet("QPushButton {background-color: red}");
        msgBox.setText("Maly krok pro cloveka, ale velky skok pro lidstvo");
        msgBox.exec();

    }
    else
    {
        iD = list[0].toInt();

        QStringList posl = list[1].split(" ",QString::SkipEmptyParts);
        location = ui->server->text()+"/stav?id=" + list[0];
        double px = posl[0].toDouble();
        double py = posl[1].toDouble();

        QStringList podl = list[4].split(" ",QString::SkipEmptyParts);
        podPosA = podl[0].toDouble();
        podPosB = podl[1].toDouble();
        pod->setRect(podPosA, 5, podPosB - podPosA, -5);
        pod->setVisible(true);

        lander->setPosition(px, py);

        QStringList lispeed = list[2].split(" ",QString::SkipEmptyParts);
        ui->speedLabel->setText(lispeed[1]);
        if(-lispeed[1].toDouble() > 5)
            ui->speedLabel->setStyleSheet("QLabel {color: red}");
        else
            ui->speedLabel->setStyleSheet("QLabel {color: green}");

        ui->speedLabel->setText(lispeed[0]);
        if(-lispeed[0].toDouble() > 5)
            ui->speedLabel_2->setStyleSheet("QLabel {color: red}");
        else if(lispeed[0].toDouble() > 5)
            ui->speedLabel_2->setStyleSheet("QLabel {color: red}");
        else
            ui->speedLabel_2->setStyleSheet("QLabel {color: green}");

        ui->fuelLabel->setText(list[3]);
        if(list[3].toDouble() < 10)
            ui->fuelLabel->setStyleSheet("QLabel {color: red}");
        else
            ui->fuelLabel->setStyleSheet("QLabel {color: green}");

        scene->update();
    }
    //msgBox.setText(str);
    //msgBox.exec();
    ui->lineEdit->setText(str);

}

void LunarLander::startLanding()
{
    QNetworkAccessManager *manager = new QNetworkAccessManager(this); //nastavi posilac pozadavku
    connect(manager, SIGNAL(finished(QNetworkReply*)),this,SLOT(replyFinished(QNetworkReply *))); //spoji s funkci replyFinished()

    manager->get(QNetworkRequest(QUrl(ui->server->text()+"/start"))); //posle pozadavek
    timer->start(100);

    scene->addItem(lander);
    pod->setVisible(true);


}

void LunarLander::keyPressEvent(QKeyEvent *event)
{
    if(event->key() == Qt::Key_W)
        on_pushButton_2_clicked();
    if(event->key() == Qt::Key_D)
        on_pushButton_4_clicked();
    if(event->key() == Qt::Key_A)
        on_pushButton_3_clicked();
}

void LunarLander::on_pushButton_clicked()
{
    startLanding();
}

void LunarLander::on_pushButton_2_clicked()
{
    if(up)
    {
        up = false;
        ui->pushButton_2->setStyleSheet("QPushButton {background-color: red}");
    }
    else
    {
        up = true;
        ui->pushButton_2->setStyleSheet("QPushButton {background-color: green}");
    }
    QNetworkAccessManager *manager = new QNetworkAccessManager(this); //nastavi posilac pozadavku
    connect(manager, SIGNAL(finished(QNetworkReply*)),this,SLOT(replyFinished(QNetworkReply *))); //spoji s funkci replyFinished()

    manager->get(QNetworkRequest(QUrl(location+"&nahoru="+QString::number(up))));
}

void LunarLander::on_pushButton_3_clicked()
{
    if(left)
    {
        left = false;
        ui->pushButton_3->setStyleSheet("QPushButton {background-color: red}");
    }
    else
    {
        left = true;
        ui->pushButton_3->setStyleSheet("QPushButton {background-color: green}");
    }
    QNetworkAccessManager *manager = new QNetworkAccessManager(this); //nastavi posilac pozadavku
    connect(manager, SIGNAL(finished(QNetworkReply*)),this,SLOT(replyFinished(QNetworkReply *))); //spoji s funkci replyFinished()

    manager->get(QNetworkRequest(QUrl(location+"&doleva="+QString::number(left))));
}

void LunarLander::on_pushButton_4_clicked()
{
    if(right)
    {
        right = false;
        ui->pushButton_4->setStyleSheet("QPushButton {background-color: red}");
    }
    else
    {
        right = true;
        ui->pushButton_4->setStyleSheet("QPushButton {background-color: green}");
    }
    QNetworkAccessManager *manager = new QNetworkAccessManager(this); //nastavi posilac pozadavku
    connect(manager, SIGNAL(finished(QNetworkReply*)),this,SLOT(replyFinished(QNetworkReply *))); //spoji s funkci replyFinished()

    manager->get(QNetworkRequest(QUrl(location+"&doprava="+QString::number(right))));
}
